@@ -18,15 +18,15 @@ import (
 	"miniflux.app/v2/internal/urllib"
 )
 
-type Atom10Adapter struct {
-	atomFeed *Atom10Feed
+type atom10Adapter struct {
+	atomFeed *atom10Feed
 }
 
-func NewAtom10Adapter(atomFeed *Atom10Feed) *Atom10Adapter {
-	return &Atom10Adapter{atomFeed}
+func NewAtom10Adapter(atomFeed *atom10Feed) *atom10Adapter {
+	return &atom10Adapter{atomFeed}
 }
 
-func (a *Atom10Adapter) BuildFeed(baseURL string) *model.Feed {
+func (a *atom10Adapter) BuildFeed(baseURL string) *model.Feed {
 	feed := new(model.Feed)
 
 	// Populate the feed URL.
@@ -40,7 +40,7 @@ func (a *Atom10Adapter) BuildFeed(baseURL string) *model.Feed {
 	}
 
 	// Populate the site URL.
-	siteURL := a.atomFeed.Links.OriginalLink()
+	siteURL := a.atomFeed.Links.originalLink()
 	if siteURL != "" {
 		if absoluteSiteURL, err := urllib.AbsoluteURL(baseURL, siteURL); err == nil {
 			feed.SiteURL = absoluteSiteURL
@@ -50,13 +50,13 @@ func (a *Atom10Adapter) BuildFeed(baseURL string) *model.Feed {
 	}
 
 	// Populate the feed title.
-	feed.Title = a.atomFeed.Title.Body()
+	feed.Title = a.atomFeed.Title.body()
 	if feed.Title == "" {
 		feed.Title = feed.SiteURL
 	}
 
 	// Populate the feed description.
-	feed.Description = a.atomFeed.Subtitle.Body()
+	feed.Description = a.atomFeed.Subtitle.body()
 
 	// Populate the feed icon.
 	if a.atomFeed.Icon != "" {
@@ -72,14 +72,14 @@ func (a *Atom10Adapter) BuildFeed(baseURL string) *model.Feed {
 	return feed
 }
 
-func (a *Atom10Adapter) populateEntries(siteURL string) model.Entries {
+func (a *atom10Adapter) populateEntries(siteURL string) model.Entries {
 	entries := make(model.Entries, 0, len(a.atomFeed.Entries))
 
 	for _, atomEntry := range a.atomFeed.Entries {
 		entry := model.NewEntry()
 
 		// Populate the entry URL.
-		entry.URL = atomEntry.Links.OriginalLink()
+		entry.URL = atomEntry.Links.originalLink()
 		if entry.URL != "" {
 			if absoluteEntryURL, err := urllib.AbsoluteURL(siteURL, entry.URL); err == nil {
 				entry.URL = absoluteEntryURL
@@ -87,16 +87,16 @@ func (a *Atom10Adapter) populateEntries(siteURL string) model.Entries {
 		}
 
 		// Populate the entry content.
-		entry.Content = atomEntry.Content.Body()
+		entry.Content = atomEntry.Content.body()
 		if entry.Content == "" {
-			entry.Content = atomEntry.Summary.Body()
+			entry.Content = atomEntry.Summary.body()
 			if entry.Content == "" {
 				entry.Content = atomEntry.FirstMediaDescription()
 			}
 		}
 
 		// Populate the entry title.
-		entry.Title = atomEntry.Title.Title()
+		entry.Title = atomEntry.Title.title()
 		if entry.Title == "" {
 			entry.Title = sanitizer.TruncateHTML(entry.Content, 100)
 			if entry.Title == "" {
@@ -105,9 +105,9 @@ func (a *Atom10Adapter) populateEntries(siteURL string) model.Entries {
 		}
 
 		// Populate the entry author.
-		authors := atomEntry.Authors.PersonNames()
+		authors := atomEntry.Authors.personNames()
 		if len(authors) == 0 {
-			authors = a.atomFeed.Authors.PersonNames()
+			authors = a.atomFeed.Authors.personNames()
 		}
 		sort.Strings(authors)
 		authors = slices.Compact(authors)
@@ -137,6 +137,8 @@ func (a *Atom10Adapter) populateEntries(siteURL string) model.Entries {
 		if len(categories) == 0 {
 			categories = a.atomFeed.Categories.CategoryNames()
 		}
+
+		// Sort and deduplicate categories.
 		sort.Strings(categories)
 		entry.Tags = slices.Compact(categories)
 
@@ -150,7 +152,7 @@ func (a *Atom10Adapter) populateEntries(siteURL string) model.Entries {
 		}
 
 		// Generate the entry hash.
-		for _, value := range []string{atomEntry.ID, atomEntry.Links.OriginalLink()} {
+		for _, value := range []string{atomEntry.ID, atomEntry.Links.originalLink()} {
 			if value != "" {
 				entry.Hash = crypto.SHA256(value)
 				break
