@@ -13,11 +13,12 @@ import (
 
 // Parse returns a normalized feed struct from a RSS feed.
 func Parse(baseURL string, data io.ReadSeeker) (*model.Feed, error) {
-	rssFeed := new(RSS)
+	rssFeed := new(rss)
 	decoder := xml.NewXMLDecoder(data)
 	decoder.DefaultSpace = "rss"
 	if err := decoder.Decode(rssFeed); err != nil {
 		return nil, fmt.Errorf("rss: unable to parse feed: %w", err)
 	}
-	return NewRSSAdapter(rssFeed).BuildFeed(baseURL), nil
+	adapter := &rssAdapter{rssFeed}
+	return adapter.buildFeed(baseURL), nil
 }
