@@ -32,9 +32,9 @@ func (h *handler) refreshCategory(w http.ResponseWriter, r *http.Request) int64
 	sess := session.New(h.store, request.SessionID(r))
 
 	// Avoid accidental and excessive refreshes.
-	if time.Now().UTC().Unix()-request.LastForceRefresh(r) < int64(config.Opts.ForceRefreshInterval())*60 {
-		time := config.Opts.ForceRefreshInterval()
-		sess.NewFlashErrorMessage(printer.Plural("alert.too_many_feeds_refresh", time, time))
+	if time.Since(request.LastForceRefresh(r)) < config.Opts.ForceRefreshInterval() {
+		interval := int(config.Opts.ForceRefreshInterval().Minutes())
+		sess.NewFlashErrorMessage(printer.Plural("alert.too_many_feeds_refresh", interval, interval))
 	} else {
 		userID := request.UserID(r)
 		// We allow the end-user to force refresh all its feeds in this category
