@@ -5,8 +5,7 @@ package form // import "miniflux.app/v2/internal/ui/form"
 
 import (
 	"net/http"
-
-	"miniflux.app/v2/internal/locale"
+	"strings"
 )
 
 // APIKeyForm represents the API Key form.
@@ -14,18 +13,9 @@ type APIKeyForm struct {
 	Description string
 }
 
-// Validate makes sure the form values are valid.
-func (a APIKeyForm) Validate() *locale.LocalizedError {
-	if a.Description == "" {
-		return locale.NewLocalizedError("error.fields_mandatory")
-	}
-
-	return nil
-}
-
 // NewAPIKeyForm returns a new APIKeyForm.
 func NewAPIKeyForm(r *http.Request) *APIKeyForm {
 	return &APIKeyForm{
-		Description: r.FormValue("description"),
+		Description: strings.TrimSpace(r.FormValue("description")),
 	}
 }
