@@ -32,6 +32,7 @@ type IntegrationForm struct {
 	WallabagClientSecret             string
 	WallabagUsername                 string
 	WallabagPassword                 string
+	WallabagTags                     string
 	NotionEnabled                    bool
 	NotionPageID                     string
 	NotionToken                      string
@@ -44,9 +45,6 @@ type IntegrationForm struct {
 	EspialTags                       string
 	ReadwiseEnabled                  bool
 	ReadwiseAPIKey                   string
-	PocketEnabled                    bool
-	PocketAccessToken                string
-	PocketConsumerKey                string
 	TelegramBotEnabled               bool
 	TelegramBotToken                 string
 	TelegramBotChatID                string
@@ -65,6 +63,11 @@ type IntegrationForm struct {
 	LinkdingAPIKey                   string
 	LinkdingTags                     string
 	LinkdingMarkAsUnread             bool
+	LinktacoEnabled                  bool
+	LinktacoAPIToken                 string
+	LinktacoOrgSlug                  string
+	LinktacoTags                     string
+	LinktacoVisibility               string
 	LinkwardenEnabled                bool
 	LinkwardenURL                    string
 	LinkwardenAPIKey                 string
@@ -97,6 +100,9 @@ type IntegrationForm struct {
 	OmnivoreEnabled                  bool
 	OmnivoreAPIKey                   string
 	OmnivoreURL                      string
+	KarakeepEnabled                  bool
+	KarakeepAPIKey                   string
+	KarakeepURL                      string
 	RaindropEnabled                  bool
 	RaindropToken                    string
 	RaindropCollectionID             string
@@ -145,6 +151,7 @@ func (i IntegrationForm) Merge(integration *model.Integration) {
 	integration.WallabagClientSecret = i.WallabagClientSecret
 	integration.WallabagUsername = i.WallabagUsername
 	integration.WallabagPassword = i.WallabagPassword
+	integration.WallabagTags = i.WallabagTags
 	integration.NotionEnabled = i.NotionEnabled
 	integration.NotionPageID = i.NotionPageID
 	integration.NotionToken = i.NotionToken
@@ -157,9 +164,6 @@ func (i IntegrationForm) Merge(integration *model.Integration) {
 	integration.EspialTags = i.EspialTags
 	integration.ReadwiseEnabled = i.ReadwiseEnabled
 	integration.ReadwiseAPIKey = i.ReadwiseAPIKey
-	integration.PocketEnabled = i.PocketEnabled
-	integration.PocketAccessToken = i.PocketAccessToken
-	integration.PocketConsumerKey = i.PocketConsumerKey
 	integration.TelegramBotEnabled = i.TelegramBotEnabled
 	integration.TelegramBotToken = i.TelegramBotToken
 	integration.TelegramBotChatID = i.TelegramBotChatID
@@ -178,6 +182,11 @@ func (i IntegrationForm) Merge(integration *model.Integration) {
 	integration.LinkdingAPIKey = i.LinkdingAPIKey
 	integration.LinkdingTags = i.LinkdingTags
 	integration.LinkdingMarkAsUnread = i.LinkdingMarkAsUnread
+	integration.LinktacoEnabled = i.LinktacoEnabled
+	integration.LinktacoAPIToken = i.LinktacoAPIToken
+	integration.LinktacoOrgSlug = i.LinktacoOrgSlug
+	integration.LinktacoTags = i.LinktacoTags
+	integration.LinktacoVisibility = i.LinktacoVisibility
 	integration.LinkwardenEnabled = i.LinkwardenEnabled
 	integration.LinkwardenURL = i.LinkwardenURL
 	integration.LinkwardenAPIKey = i.LinkwardenAPIKey
@@ -209,6 +218,9 @@ func (i IntegrationForm) Merge(integration *model.Integration) {
 	integration.OmnivoreEnabled = i.OmnivoreEnabled
 	integration.OmnivoreAPIKey = i.OmnivoreAPIKey
 	integration.OmnivoreURL = i.OmnivoreURL
+	integration.KarakeepEnabled = i.KarakeepEnabled
+	integration.KarakeepAPIKey = i.KarakeepAPIKey
+	integration.KarakeepURL = i.KarakeepURL
 	integration.RaindropEnabled = i.RaindropEnabled
 	integration.RaindropToken = i.RaindropToken
 	integration.RaindropCollectionID = i.RaindropCollectionID
@@ -260,6 +272,7 @@ func NewIntegrationForm(r *http.Request) *IntegrationForm {
 		WallabagClientSecret:             r.FormValue("wallabag_client_secret"),
 		WallabagUsername:                 r.FormValue("wallabag_username"),
 		WallabagPassword:                 r.FormValue("wallabag_password"),
+		WallabagTags:                     r.FormValue("wallabag_tags"),
 		NotionEnabled:                    r.FormValue("notion_enabled") == "1",
 		NotionPageID:                     r.FormValue("notion_page_id"),
 		NotionToken:                      r.FormValue("notion_token"),
@@ -272,9 +285,6 @@ func NewIntegrationForm(r *http.Request) *IntegrationForm {
 		EspialTags:                       r.FormValue("espial_tags"),
 		ReadwiseEnabled:                  r.FormValue("readwise_enabled") == "1",
 		ReadwiseAPIKey:                   r.FormValue("readwise_api_key"),
-		PocketEnabled:                    r.FormValue("pocket_enabled") == "1",
-		PocketAccessToken:                r.FormValue("pocket_access_token"),
-		PocketConsumerKey:                r.FormValue("pocket_consumer_key"),
 		TelegramBotEnabled:               r.FormValue("telegram_bot_enabled") == "1",
 		TelegramBotToken:                 r.FormValue("telegram_bot_token"),
 		TelegramBotChatID:                r.FormValue("telegram_bot_chat_id"),
@@ -293,6 +303,11 @@ func NewIntegrationForm(r *http.Request) *IntegrationForm {
 		LinkdingAPIKey:                   r.FormValue("linkding_api_key"),
 		LinkdingTags:                     r.FormValue("linkding_tags"),
 		LinkdingMarkAsUnread:             r.FormValue("linkding_mark_as_unread") == "1",
+		LinktacoEnabled:                  r.FormValue("linktaco_enabled") == "1",
+		LinktacoAPIToken:                 r.FormValue("linktaco_api_token"),
+		LinktacoOrgSlug:                  r.FormValue("linktaco_org_slug"),
+		LinktacoTags:                     r.FormValue("linktaco_tags"),
+		LinktacoVisibility:               r.FormValue("linktaco_visibility"),
 		LinkwardenEnabled:                r.FormValue("linkwarden_enabled") == "1",
 		LinkwardenURL:                    r.FormValue("linkwarden_url"),
 		LinkwardenAPIKey:                 r.FormValue("linkwarden_api_key"),
@@ -324,6 +339,9 @@ func NewIntegrationForm(r *http.Request) *IntegrationForm {
 		OmnivoreEnabled:                  r.FormValue("omnivore_enabled") == "1",
 		OmnivoreAPIKey:                   r.FormValue("omnivore_api_key"),
 		OmnivoreURL:                      r.FormValue("omnivore_url"),
+		KarakeepEnabled:                  r.FormValue("karakeep_enabled") == "1",
+		KarakeepAPIKey:                   r.FormValue("karakeep_api_key"),
+		KarakeepURL:                      r.FormValue("karakeep_url"),
 		RaindropEnabled:                  r.FormValue("raindrop_enabled") == "1",
 		RaindropToken:                    r.FormValue("raindrop_token"),
 		RaindropCollectionID:             r.FormValue("raindrop_collection_id"),
