@@ -45,6 +45,7 @@ func (h *handler) showIntegrationPage(w http.ResponseWriter, r *http.Request) {
 		WallabagClientSecret:             integration.WallabagClientSecret,
 		WallabagUsername:                 integration.WallabagUsername,
 		WallabagPassword:                 integration.WallabagPassword,
+		WallabagTags:                     integration.WallabagTags,
 		NotionEnabled:                    integration.NotionEnabled,
 		NotionPageID:                     integration.NotionPageID,
 		NotionToken:                      integration.NotionToken,
@@ -75,6 +76,11 @@ func (h *handler) showIntegrationPage(w http.ResponseWriter, r *http.Request) {
 		LinkdingAPIKey:                   integration.LinkdingAPIKey,
 		LinkdingTags:                     integration.LinkdingTags,
 		LinkdingMarkAsUnread:             integration.LinkdingMarkAsUnread,
+		LinktacoEnabled:                  integration.LinktacoEnabled,
+		LinktacoAPIToken:                 integration.LinktacoAPIToken,
+		LinktacoOrgSlug:                  integration.LinktacoOrgSlug,
+		LinktacoTags:                     integration.LinktacoTags,
+		LinktacoVisibility:               integration.LinktacoVisibility,
 		LinkwardenEnabled:                integration.LinkwardenEnabled,
 		LinkwardenURL:                    integration.LinkwardenURL,
 		LinkwardenAPIKey:                 integration.LinkwardenAPIKey,
