@@ -13,22 +13,16 @@ import (
 )
 
 func (h *handler) showFavicon(w http.ResponseWriter, r *http.Request) {
-	etag, err := static.GetBinaryFileChecksum("favicon.ico")
-	if err != nil {
+	value, ok := static.BinaryBundles["favicon.ico"]
+	if !ok {
 		html.NotFound(w, r)
 		return
 	}
 
-	response.New(w, r).WithCaching(etag, 48*time.Hour, func(b *response.Builder) {
-		blob, err := static.LoadBinaryFile("favicon.ico")
-		if err != nil {
-			html.ServerError(w, r, err)
-			return
-		}
-
+	response.New(w, r).WithCaching(value.Checksum, 48*time.Hour, func(b *response.Builder) {
 		b.WithHeader("Content-Type", "image/x-icon")
 		b.WithoutCompression()
-		b.WithBody(blob)
+		b.WithBody(value.Data)
 		b.Write()
 	})
 }
